// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.controllers' is found in controllers.js
angular.module('starter', ['ionic', 'starter.controllers', 'starter.services','ngSanitize','MassAutoComplete'])

.filter('dateToISO', function() {
return function(input) {
	input = new Date(input).toISOString();
	return input;
};
})

.filter('zpad', function() {
	return function(input, n) {
		if(input === undefined)
			input = ""
		if(input.length >= n)
			return input
		var zeros = "0".repeat(n);
		return (zeros + input).slice(-1 * n)
	};
})

.filter('percentage', ['$filter', function ($filter) {
	return function (input, decimals) {
		return Number.isInteger(parseFloat(input)) && parseFloat(input) > 0 ? $filter('number')(input) + '%' : $filter('number')(input * 100, decimals) + '%';
	};
}])

.filter('telephone', function(){
	return function (number) {
		if (!number) { return ''; }
		number = String(number);
		number = number.replace(/[^0-9]*/g, '');
		var formattedNumber = number;

		var c = (number[0] == '1') ? '1' : '';
		number = number[0] == '1' ? number.slice(1) : number;

		var area = number.substring(0, 3);
		var front = number.substring(3, 6);
		var end = number.substring(6, 10);

		if (front) {
				formattedNumber = (c + "(" + area + ") " + front);
		}
		if (end) {
				formattedNumber += ("-" + end);
		}
		return formattedNumber;
	};
})

.directive('upload', ['$http', '$ionicPopup', function($http, $ionicPopup) {
	return {
		restrict: 'E',
		replace: true,
		scope: false,
		require: '?ngModel',
		template: '<div class="asset-upload">Suelta un archivo aquí</div>',
		link: function(scope, element, attrs, ngModel) {

			element.on('dragover', function(e) {
					e.preventDefault();
					e.stopPropagation();
			});
			element.on('dragenter', function(e) {
					e.preventDefault();
					e.stopPropagation();
			});
			
			element.on('drop', function(e) {
					e.preventDefault();
					e.stopPropagation();
					if (e.dataTransfer){
							if (e.dataTransfer.files.length > 0) {
									upload(e.dataTransfer.files, attrs);
							}
					}
					return false;
			});
			
			var upload = function(files, attr) {
				var data = new FormData();
				angular.forEach(files, function(value){
					data.append("files[]", value);
				});
		
				data.append("objectId", ngModel.$viewValue);
				// scope.upload(files, attrs, data);
				// var fd = new FormData();
				// fd.append('file', files);
				$http.post('https://api.avanzamas.net/upload/'+ngModel.$viewValue.target+'/'+ngModel.$viewValue.type+'/'+ngModel.$viewValue.id, data, {
					transformRequest: angular.identity,
					headers: { 'auth-token' : localStorage.token, 'Enviroment': localStorage.enviroment,'Content-Type': undefined },
				})
				.success(function(){
				})
				.error(function(){
				});
			};
		}
	};
}])

// .constant('ApiEndpoint', {
//   url: 'https://avanzamas.masvector.com/api/'
// })

.constant('ApiEndpoint', {
  url: 'https://api.avanzamas.net/'
})

.directive("selectableText", function() {
	return {
	  restrict: "A",
	  template: function(element) {
	    return '<input type="text" readonly value="'+element[0].textContent+'">';
	  }
	};
})

.directive('format', ['$filter', function ($filter) {
    return {
        require: '?ngModel',
        link: function (scope, elem, attrs, ctrl, ngModel) {
			
		switch(attrs.format){
			case 'percentage':
					elem.bind('focus', function(event) {
						var plainNumber = elem.val().replace(/[^\d|\-+|\.+]/g, '');
						elem.val(plainNumber);
					});
		
					elem.bind('blur', function(event) {
						var plainNumber = elem.val().replace(/[^\d|\-+|\.+]/g, '');
						elem.val($filter(attrs.format)(plainNumber*0.01));
					});
			case 'currency':
				if (!ctrl) return;
				elem.min = attrs.min;
				elem.max = attrs.max;
	
				ctrl.$formatters.unshift(function (a) {
					if(ctrl.$modelValue<attrs.min){
						return;
					}
					if(ctrl.$modelValue>attrs.max){
						return;
					}
					return $filter(attrs.format)(ctrl.$modelValue)
				});
				
				elem.bind('focus', function(event) {
					var plainNumber = elem.val().replace(/[^\d|\-+|\.+]/g, '');
					elem.val(plainNumber);
				});
	
				elem.bind('blur', function(event) {
					var plainNumber = elem.val().replace(/[^\d|\-+|\.+]/g, '');
					elem.val($filter(attrs.format)(plainNumber));
				});
			break;
			case 'date':
				ctrl.$formatters.push(function(fromModel){
					fromModel = new Date((new Date(fromModel).getTime()) + (new Date().getTimezoneOffset()*60000)+3600000);
					return fromModel;
				});

				ctrl.$parsers.push(function(fromField){
					fromField = $filter(attrs.format)(fromField, 'yyyy-MM-dd')
					return fromField;
				});
			break;
			case 'number':
				elem.bind('focus', function(event) {
					var plainNumber = parseInt(elem.val());
					elem.val(plainNumber);
				});
	
				elem.bind('blur', function(event) {
					var plainNumber = parseInt(elem.val());
					elem.val($filter(attrs.format)(plainNumber));
				});
			break;
		}
      }
    };
}])

.directive('capitalize', function() {
	return {
		require: 'ngModel',
		link: function(scope, element, attrs, modelCtrl) {
		var capitalize = function(inputValue) {
			if (inputValue == undefined) inputValue = '';
			var capitalized = inputValue.toUpperCase();
			if (capitalized !== inputValue) {
			// see where the cursor is before the update so that we can set it back
			var selection = element[0].selectionStart;
			modelCtrl.$setViewValue(capitalized);
			modelCtrl.$render();
			// set back the cursor after rendering
			element[0].selectionStart = selection;
			element[0].selectionEnd = selection;
			}
			return capitalized;
		}
		modelCtrl.$parsers.push(capitalize);
		capitalize(scope[attrs.ngModel]); // capitalize initial value
		}
	};
})

.run(function ($rootScope, $state, AuthService, AUTH_EVENTS) {
	$rootScope.$on('$stateChangeStart', function (event,next, nextParams, fromState) {
		if (!AuthService.isAuthorized(next.name)) {
			console.log('not autorized for:'+next.name);
			if (next.name !== 'app.login') {
			event.preventDefault();
			//$state.go($state.current, {}, {reload: true});
			$rootScope.$broadcast(AUTH_EVENTS.notAuthorized);
			}
		}  
		if (!AuthService.isAuthenticated()) {
			if (next.name !== 'app.login') {
			event.preventDefault();
			$state.go('app.login');
			}
		}
	});
  })

.run(function($ionicPlatform) {
  $ionicPlatform.ready(function() {
    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
      cordova.plugins.Keyboard.disableScroll(true);
    }
    if (window.StatusBar) {
      StatusBar.styleDefault();
    }
  });
})

.config(function($stateProvider, $urlRouterProvider) {
	$stateProvider
	
	.state('app', {
		url: '/app',
		abstract: true,
		templateUrl: 'templates/menu.html',
		controller: 'AppCtrl'
	})

	.state('app.login', {
		url: '/login',
		views: {
			'menuContent': {
				templateUrl: 'templates/login.html',
				controller: 'LoginCtrl'
			}
		}
	})

	.state('app.stats', {
		url: '/stats',
		views: {
			'menuContent': {
				templateUrl: 'templates/stats.html',
				controller: 'StatsCtrl'
			}
		}
	})

	.state('app.statsDistribuidor', {
		url: '/stats/distribuidor/:DistribuidorId',
		views: {
			'menuContent': {
				templateUrl: 'templates/stats.html',
				controller: 'StatsDistribuidorCtrl'
			}
		}
	})
	
	.state('app.clientes', {
		url: '/clientes',
		views: {
			'menuContent': {
				templateUrl: 'templates/clientes.html',
				controller: 'ClientesCtrl'
			}
		}
	})

	.state('app.distribuidores', {
		url: '/distribuidores',
		views: {
			'menuContent': {
				templateUrl: 'templates/clientes.html',
				controller: 'DistribuidoresCtrl'
			}
		}
	})

	.state('app.promotoria', {
		url: '/promotoria',
		views: {
			'menuContent': {
				templateUrl: 'templates/clientes.html',
				controller: 'PromotoriaCtrl'
			}
		}
	})
	
	.state('app.clientesInfoFaltante', {
		url: '/clientes/buro/faltantes',
		views: {
			'menuContent': {
				templateUrl: 'templates/clientesInfoFaltante.html',
				controller: 'ClientesInfoFaltanteCtrl'
			}
		}
	})
	
	.state('app.clienteFromExcel', {
		url: '/clienteFromExcel/:ClienteId',
		views:{
			'menuContent' : {
				templateUrl: 'templates/cliente.html',
				controller: 'ClienteFromExcelCtrl'
			}
		}
	})
	
	.state('app.cliente', {
		url: '/cliente/:ClienteId',
		views:{
			'menuContent' : {
				templateUrl: 'templates/cliente.html',
				controller: 'ClienteCtrl'
			}
		}
	})

	.state('app.distribuidor', {
		url: '/distribuidor/:ClienteId',
		views:{
			'menuContent' : {
				templateUrl: 'templates/cliente.html',
				controller: 'ClienteCtrl'
			}
		}
	})
	
	.state('app.pagares', {
		url: '/pagare/:ClienteId',
		views:{
			'menuContent' : {
				templateUrl: 'templates/pagares.html',
				controller: 'PagaresCtrl'
			}
		}
	})

	.state('app.productos', {
		url: '/productos',
		views: {
			'menuContent': {
				templateUrl: 'templates/productos.html',
				controller: 'ProductosCtrl'
			}
		}
	})

	.state('app.contratos', {
		url: '/contratos',
		views: {
			'menuContent': {
				templateUrl: 'templates/contratos.html',
				controller: 'ContratosCtrl'
			}
		}
	})
	
	.state('app.contrato', {
		url: '/contrato/:ContratoId',
		views: {
			'menuContent': {
				templateUrl: 'templates/contrato.html',
				controller: 'ContratoCtrl'
			}
		}
	})

	.state('app.new_contrato', {
		url: '/contrato/new/:ClienteId',
		views: {
			'menuContent': {
				templateUrl: 'templates/contrato.html',
				controller: 'ContratoCtrl'
			}
		}
	})

	.state('app.vales', {
		url: '/vales',
		views: {
			'menuContent': {
				templateUrl: 'templates/vales.html',
				controller: 'ValesCtrl'
			}
		}
	})

	.state('app.caja', {
		url: '/caja',
		views: {
			'menuContent': {
				templateUrl: 'templates/caja.html',
				controller: 'CajaCtrl'
			}
		}
	})

	.state('app.cajaHistorial', {
		url: '/caja/historial/distribuidor/:DistribuidorId',
		views: {
			'menuContent': {
				templateUrl: 'templates/caja_historial.html',
				controller: 'CajaHistorialCtrl'
			}
		}
	})

	.state('app.reportedeIngresos', {
		url: '/reporte/ingresos',
		views: {
			'menuContent': {
				templateUrl: 'templates/reporte_ingresos.html',
				controller: 'ReportedeIngresosCtrl'
			}
		}
	})

	.state('app.fechadeReporte', {
		url: '/reporte/ingresos/:FechadeReporte',
		views: {
			'menuContent': {
				templateUrl: 'templates/reporte_ingresos_detalle.html',
				controller: 'FechadeReporteCtrl'
			}
		}
	})

	.state('app.usuarios', {
		url: '/usuarios',
		views: {
			'menuContent': {
				templateUrl: 'templates/usuarios.html',
				controller: 'UsuariosCtrl'
			}
		}
	})

	.state('app.bitacoras', {
		url: '/bitacoras',
		views: {
			'menuContent': {
				templateUrl: 'templates/bitacoras.html',
				controller: 'BitacorasCtrl'
			}
		}
	})
	.state('app.solicitudes', {
		url: '/solicitudes',
		views: {
			'menuContent': {
				templateUrl: 'templates/solicitudes.html',
				controller: 'SolicitudesCtrl'
			}
		}
	})
	.state('app.solicitud_new',{
		url: '/solicitud/nueva',
		views:{
			'menuContent' : {
				templateUrl: 'templates/solicitud_new.html',
				controller: 'SolicitudNewCtrl'
			}
		}
	})
	.state('app.solicitud', {
		url: '/solicitud/:SolicitudId',
		views:{
			'menuContent' : {
				templateUrl: 'templates/solicitud.html',
				controller: 'SolicitudCtrl'
			}
		}
	})
	.state('app.analisis', {
		url: '/analisis/:SolicitudId',
		views:{
			'menuContent' : {
				templateUrl: 'templates/solicitud_analisis.html',
				controller: 'SolicitudAnalisisCtrl'
			}
		}
	})
	.state('app.formalizacion', {
		url: '/formalizacion/:Id',
		views:{
			'menuContent' : {
				templateUrl: 'templates/formalizar.html',
				controller: 'SolicitudesCtrl'
			}
		}
	})
	.state('app.disperciones', {
		url: '/disperciones/:Id',
		views:{
			'menuContent' : {
				templateUrl: 'templates/disperciones.html',
				controller: 'SolicitudesCtrl'
			}
		}
	})
	.state('app.canjearVale', {
		url: '/canjearVale',
		views:{
			'menuContent' : {
				templateUrl: 'templates/canjear_vale.html',
				controller: 'CanjearValeCtrl'
			}
		}
	})

	.state('app.pagos', {
		url: '/pagos',
		views:{
			'menuContent' : {
				templateUrl: 'templates/pagos.html',
				controller: 'PagosCtrl'
			}
		}
	})
	
	.state('app.reportes', {
		url: '/reportes',
		views:{
			'menuContent' : {
				templateUrl: 'templates/reportes.html',
				controller: 'ReportesCtrl'
			}
		}
	})

	.state('app.reporte', {
		url: '/reporte',
		views:{
			'menuContent' : {
				templateUrl: 'templates/reporte.html',
				controller: 'ReporteCtrl'
			}
		}
	})

	.state('app.asuetos', {
		url: '/asuetos',
		views:{
			'menuContent' : {
				templateUrl: 'templates/asuetos.html',
				controller: 'AsuetosCtrl'
			}
		}
	})
	;
  
	$urlRouterProvider.otherwise('/app/canjearVale');
  
});
